import * as React from 'react';
import * as _ from 'lodash';
// import update from 'immutability-helper';

import {
  Checkbox,
  Container,
  Label,
  Accordion,
  Icon,
  List, Button,
  ListItemProps,
  CheckboxProps,
} from 'semantic-ui-react';


import MetaSensorItemType from '../../api/model/MetaSensorItemType';
import MetaSensorItem from '../../api/model/MetaSensorItem';

import * as Utils from '@overflow/commons/utils/Utils';




export interface SensorItemTreeStateProps {
}

export interface SensorItemTreeDispatchProps {
  onReadAll?(): void;
}


export type SensorItemTreeProps = SensorItemTreeStateProps & SensorItemTreeDispatchProps;


export interface SensorItemTreeState {
  categoryState: Map<number, boolean>;
  itemState: Map<number, Array<boolean>>;
}

interface TreeItem {
  metaSensorItemList: Array<MetaSensorItem>;
  metaSensorItemType: MetaSensorItemType;
}

export class SensorItemTree extends React.Component<SensorItemTreeProps, SensorItemTreeState> {

  private itemMap: Map<number, TreeItem>;
  private selectedItemMap: Map<number, Array<MetaSensorItem>>;

  constructor(props: any, context: any) {
    super(props, context);

    this.itemMap = new Map;
    this.selectedItemMap = new Map,

      this.state = {
        categoryState: new Map(),
        itemState: new Map(),
      };
    this.sortItemMap();

    // fs.readFile('../../../../../dh.json', this.handlJSONFile);
  }

  public sortItemMap(): void {

    SensorJsonData.map((data: any, idx: number) => {
      let sensorItem: MetaSensorItem = data;

      if (this.itemMap.has(sensorItem.metaSensorItemType.id)) {
        this.itemMap.get(sensorItem.metaSensorItemType.id).metaSensorItemList.push(sensorItem);
      } else {
        let item: TreeItem = { metaSensorItemList: null, metaSensorItemType: null };
        item.metaSensorItemList = [];
        item.metaSensorItemList.push(sensorItem);
        item.metaSensorItemType = this.GetMetaSensorItemType(sensorItem.metaSensorItemType.id);
        this.itemMap.set(sensorItem.metaSensorItemType.id, item);
      }
    });
  }

  public ViewSensorItemType(): JSX.Element[] {
    let elems: JSX.Element[] = new Array();

    this.itemMap.forEach((data: TreeItem, key: number) => {
      // this.state.itemState[key] = new Array(data.metaSensorItemList.length).fill(false);
      elems.push(
        <List.Item key={key + 1} >
          <List.Icon name={this.state.categoryState[key] ? 'chevron up' : 'chevron down'} onClick={() => {

            {/*let newPortState: Map<number, boolean> = new Map(this.state.portState);*/ }
            let newCategoryState: Map<number, boolean> = _.clone(this.state.categoryState);
            newCategoryState[key] = !newCategoryState[key];
            this.setState({ categoryState: newCategoryState });

          }} />
          <List.Content>
            <List.Header> <Checkbox label={data.metaSensorItemType.name} onChange={
              (event: React.FormEvent<HTMLInputElement>, checkProps: CheckboxProps) => {
                let newItemState: Map<number, Array<boolean>> = _.clone(this.state.itemState);
                if (newItemState[key] === undefined) {
                  newItemState[key] = new Array(data.metaSensorItemList.length).fill(false);
                }
                newItemState[key].fill(checkProps.checked);
                if (checkProps.checked) {
                  this.selectedItemMap[key] = _.clone(data.metaSensorItemList);
                } else {
                  this.selectedItemMap[key].length = 0;
                }
                this.setState({ itemState: newItemState });
              }} />   </List.Header>
            <List.Description>Category</List.Description>
            {this.state.categoryState[key] ? this.ViewSensorItem(data.metaSensorItemList, key) : ''}
          </List.Content>
        </List.Item>,
      );
    });

    return elems;
  }

  public ViewSensorItem(metaSensorItemList: MetaSensorItem[], parentKey: number): JSX.Element[] {
    let elems: JSX.Element[] = new Array();

    if (this.state.itemState[parentKey] === undefined) {
      this.state.itemState[parentKey] = new Array(metaSensorItemList.length).fill(false);
    }

    metaSensorItemList.map((item: MetaSensorItem, idx: number) => {
      elems.push(
        <List.List key={String(parentKey) + String(idx)} onClick={() => {

          {/*let newPortState: Map<number, boolean> = new Map(this.state.portState);*/ }
          let newItemState: Map<number, Array<boolean>> = _.clone(this.state.itemState);
          newItemState[parentKey][idx] = !newItemState[parentKey][idx];
          this.setState({ itemState: newItemState });

        }}>
          <List.Item >
            <List.Icon name='file' />
            <List.Content>
              <List.Header> <Checkbox label={item.name} checked={this.state.itemState[parentKey][idx]} onChange={
                (event: React.FormEvent<HTMLInputElement>, checkProps: CheckboxProps) => {
                  if(this.selectedItemMap[parentKey] === undefined) {
                    this.selectedItemMap[parentKey] = [];
                  }
                  if (checkProps.checked) {
                    this.selectedItemMap[parentKey].push(item);
                  } else {
                    let index: number = this.selectedItemMap[parentKey].indexOf(item);
                    if(index >= 0) {
                      this.selectedItemMap[parentKey].splice(index, 1);
                    }
                  }
                }} /></List.Header>
              <List.Description>Sensor Item</List.Description>
            </List.Content>
          </List.Item>
        </List.List>,
      );
    });

    return elems;
  }

  public render(): JSX.Element {
    return (
      <Container>
        <List selection>
          {this.ViewSensorItemType()}
        </List>
        <Button label='test' onClick={() => {
          console.log(this.selectedItemMap);
        }} />
      </Container>
    );
  }

  private GetMetaSensorItemType(id: number): MetaSensorItemType {

    for (let i: number = 0; i < SensorTypeJsonData.length; ++i) {
      let msit: MetaSensorItemType = SensorTypeJsonData[i];
      if (msit.id === id) {
        return msit;
      }
    }
    return null;
    // SensorTypeJsonData.map((data: any, idx: number) => {
    //   let msit: MetaSensorItemType = data;
    //   if (msit.id === id) {
    //     return msit;
    //   }
    //   return null;
    // });
    // return null;
  }

}

const SensorTypeJsonData: any = [
  {
    'id': 1,
    'create_date': '2017-06-26T10:49:39Z',
    'description': 'CPU blah blah blah',
    'name': 'CPU',
  },
  {
    'id': 2,
    'create_date': '2017-06-26T10:49:39Z',
    'description': 'MEMORY blah blah blah',
    'name': 'MEMORY',
  },
  {
    'id': 3,
    'create_date': '2017-06-26T10:49:39Z',
    'description': 'DISK blah blah blah',
    'name': 'DISK',
  },
];

const SensorJsonData = [
  {
    'id': 1,
    'create_date': '2017-06-26T11:10:08Z',
    'key': 'cpu.usage',
    'name': 'CPU USAGE',
    'metaSensorItemType': {
      'id': 1,
    },
  },
  {
    'id': 2,
    'create_date': '2017-06-26T11:10:08Z',
    'key': 'cpu.free',
    'name': 'CPU FREE',
    'metaSensorItemType': {
      'id': 1,
    },
  },
  {
    'id': 3,
    'create_date': '2017-06-26T11:10:08Z',
    'key': 'mem.usage',
    'name': 'MEMORY USAGE',
    'metaSensorItemType': {
      'id': 2,
    },
  },
  {
    'id': 4,
    'create_date': '2017-06-26T11:10:08Z',
    'key': 'mem.free',
    'name': 'MEMORY FREE',
    'metaSensorItemType': {
      'id': 2,
    },
  },
];

export default SensorItemTree;
