import * as React from 'react';
import { Table, Header, Container, Form, Checkbox, Button } from 'semantic-ui-react';
import { ListContainer } from '@overflow/commons/react/component/ListContainer';
import Probe from '@overflow/probe/api/model/Probe';
import Domain from '@overflow/domain/api/model/Domain';

export interface StateProps {
}

export interface DispatchProps {
  onReadAllByDomain(domain: Domain): void;
  onProbeSelection(id: string): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
  selected: Probe;
  list: Probe[];
}

export class ProbeList extends React.Component<Props, State> {

  private data: any;

  constructor(props: Props, context: State) {
    super(props, context);

    this.state = {
      selected: null,
      list: null,
    };
  }

  public componentWillMount(): void {
    this.data = [
      {
        'id': '11',
        'status': {
          'name': 'STARTED',
        },
        'domain': {
          'name': 'insanity\'s domain',
        },
        'cidr': '192.168.1.0/24',
        'displayName': '192.168.1.105\'s probe',
        // 'infraHost': {
        //   'ip': '192.168.1.105',
        //   'mac': 'ab:cd:ef:gh:ij',
        // },
        'targetCount': '20',
        'sensorCount': '30',
        'probeKey': '1AGBLKDFJ2452ASDGFL2KWJLKSDJ',
        'description': 'description1111111111',
      },
      {
        'id': '22',
        'status': {
          'name': 'STARTED',
        },
        'domain': {
          'name': 'insanity\'s domain',
        },
        'displayName': '192.168.1.105\'s probe',
        'cidr': '192.168.1.0/24',
        'targetCount': '20',
        'sensorCount': '30',
        'probeKey': '1AGBLKDFJ2452ASDGFL2KWJLKSDJ',
        'description': 'description1111111111',
      },
      {
        'id': '33',
        'status': {
          'name': 'STARTED',
        },
        'domain': {
          'name': 'insanity\'s domain',
        },
        'cidr': '192.168.1.0/24',
        'displayName': '192.168.1.105\'s probe',
        'targetCount': '20',
        'sensorCount': '30',
        'probeKey': '1AGBLKDFJ2452ASDGFL2KWJLKSDJ',
        'description': 'description1111111111',
      },
    ];
    this.setState({
      list: this.data,
    });
  }

  public checkCellStatus(status: any): boolean {
    if (status.name === 'STOPPED') {
      return true;
    }
    return false;
  }

  public handleSelect(selectedProbe: any): void {
    this.setState({
      selected: selectedProbe,
    });

    this.props.onProbeSelection(selectedProbe.id);
  }

  public handleSearch = (result: Probe[]): void => {
    this.setState({
      list: result,
    });
  }

  public handleFilter(filterStr: string): void {
    if (filterStr === null) {
      this.setState({
        list: this.data,
      });
      return;
    }
    let founds = new Array();
    for (let probe of this.data) {
      if (probe.metaProbeStatus.name.indexOf(filterStr) !== -1) {
        founds.push(probe);
      }
    }
    this.setState({
      list: founds,
    });
  }

  public render(): JSX.Element {
    let probeList =
      <Container fluid>
        <Table selectable striped celled>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell textAlign={'center'}>Name</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>CIDR</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>IP</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Status</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Target Count</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Sensor Count</Table.HeaderCell>
            </Table.Row>
          </Table.Header>

          <Table.Body>
            {this.renderRows()}
          </Table.Body>
        </Table>
      </Container>;

    return (
      <ListContainer
        contents={probeList}
        data={this.data}
        onSearch={this.handleSearch}
        filter={<ProbeFilter onFilter={this.handleFilter.bind(this)} />}
      />
    );
  }

  private renderRows(): (JSX.Element | JSX.Element[]) {
    if (this.state.list.length === 0) {
      return <Table.Row error >
        <Table.Cell textAlign='center' colSpan='6'>No results found.</Table.Cell>
      </Table.Row>;
    }
    return this.state.list.map((probe: any, index: number) => (
      <Table.Row key={index} onClick={this.handleSelect.bind(this, probe)}>
        <Table.Cell >{probe.displayName}</Table.Cell>
        <Table.Cell>{probe.cidr}</Table.Cell>
        <Table.Cell>todo</Table.Cell>
        <Table.Cell negative={this.checkCellStatus(probe.status)} textAlign={'center'}>{probe.status.name}</Table.Cell>
        <Table.Cell textAlign={'center'} >{probe.targetCount}</Table.Cell>
        <Table.Cell textAlign={'center'} >{probe.sensorCount}</Table.Cell>
      </Table.Row>
    ));
  }

}

export class ProbeFilter extends React.Component<any, any> {

  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
      status: null,
    };
  }

  public handleChange(e: any, data: any): void {
    this.setState({
      status: data.value,
    });
    this.props.onFilter(data.value);
  }
  public handleReset(e: any, data: any): void {
    this.setState({
      status: null,
    });
    this.props.onFilter(null);
  }

  public render(): JSX.Element {
    // todo. getting MetaProbeStatus
    let metaProbeStatus = [
      {
        'id': '1',
        'name': 'STARTED',
      },
      {
        'id': '2',
        'name': 'STOPPED',
      },
    ];
    return (
      <Form>
        <Container fluid>
          <Button size='mini' floated='right' basic content='Reset' onClick={this.handleReset.bind(this)} />
          <Form.Field>
            <b>Status</b>
          </Form.Field>

          {metaProbeStatus.map((item: any, index: number) => (
            <Form.Field key={index}>
              <Checkbox
                radio
                label={item.name}
                name='status'
                value={item.name}
                checked={this.state.status === item.name}
                onChange={this.handleChange.bind(this)}
              />
            </Form.Field>
          ))}
        </Container>
      </Form>
    );
  }
}



