import * as React from 'react';
import { Icon, Step, Button, Table, Radio, Form, Container, Checkbox } from 'semantic-ui-react';
import { Grid, Image, Label, Segment, Dropdown, Input, List, Accordion, Loader } from 'semantic-ui-react';

import MetaCrawler from '@overflow/meta/api/model/MetaCrawler';

import SensorItemTree from '@overflow/meta/react/SensorItemTree';

export interface SensorConfigurationStateProps {

}

export interface SensorConfigurationDispatchProps {

}

export interface SensorConfigurationState {

}

export type SensorConfigurationProps = SensorConfigurationStateProps & SensorConfigurationDispatchProps;

export class SensorConfiguration extends React.Component<SensorConfigurationProps, SensorConfigurationState> {

  constructor(props: SensorConfigurationProps, context: SensorConfigurationState) {
    super(props, context);
    this.state = {
    };
  }


  public render(): JSX.Element {
    let steps = [<CrawlerSelector />, <SensorItemTree />, <ETCSelector />];

    return (
      <ConfigStepper steps={steps} />
    );
  }
}


export interface ConfigStepperProps {
  steps: Array<JSX.Element>;
}

export interface ConfigStepperState {
  currentStep: number;
}

export class ConfigStepper extends React.Component<ConfigStepperProps, ConfigStepperState> {

  constructor(props: ConfigStepperProps, context: ConfigStepperState) {
    super(props, context);
    this.state = {
      currentStep: 1,
    };
  }

  public handleActive(idx: number): boolean {
    if (this.state.currentStep === idx) {
      return true;
    }
    return false;
  }

  public handleCompleted(idx: number): boolean {
    if (this.state.currentStep > idx) {
      return true;
    }
    return false;
  }

  public handlePrev(event: React.SyntheticEvent<HTMLAnchorElement>, data: object): void {
    let step: number = this.state.currentStep;
    if (step <= 1) {
      step = 1;
    } else {
      step--;
    }
    this.setState({
      currentStep: step,
    });
  }
  public handleNext(event: React.SyntheticEvent<HTMLAnchorElement>, data: object): void {
    let step: number = this.state.currentStep;
    if (step >= this.props.steps.length + 1) {
      step = this.props.steps.length + 1;
    } else {
      step++;
    }
    this.setState({
      currentStep: step,
    });
    if (step === this.props.steps.length + 1) {
      console.log('Done');
    }
  }

  public showContent(): any {
    return this.props.steps[this.state.currentStep - 1];
  }

  public checkPrevDisabled(): boolean {
    if (this.state.currentStep <= 1) {
      return true;
    } else {
      return false;
    }
  }

  public checkNextDisabled(): boolean {
    if (this.state.currentStep === this.props.steps.length + 1) {
      return true;
    } else {
      return false;
    }
  }

  public render(): JSX.Element {
    return (
      <Container fluid>
        <Step.Group fluid>
          <Step active={this.handleActive(1)} completed={this.handleCompleted(1)}>
            <Icon name='settings' />
            <Step.Content title='Step 1' description='골라골라 크롤러를 골라' />
          </Step>

          <Step active={this.handleActive(2)} completed={this.handleCompleted(2)}>
            <Icon name='list ul' />
            <Step.Content title='Step 2' description='골라골라 아이템도 골라' />
          </Step>

          <Step active={this.handleActive(3)} completed={this.handleCompleted(3)}>
            <Icon name='options' />
            <Step.Content title='Step 3' description='나머지도 골라 아 빨리' />
          </Step>
        </Step.Group>
        <br />
        {this.showContent()}
        <br />
        <Button.Group floated='right'> {/* floated 사용시 레이아웃 깨지는 현상 */}
          <Button content='Prev' icon='left arrow' labelPosition='left'
            onClick={this.handlePrev.bind(this)} disabled={this.checkPrevDisabled()} />
          <Button.Or />
          <Button content='Next' icon='right arrow' labelPosition='right' positive
            onClick={this.handleNext.bind(this)} disabled={this.checkNextDisabled()} />
        </Button.Group>
        <br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/><br/>
      </Container>
    );
  }
}

export interface CrawlerSelectorProps {

}

export interface CrawlerSelectorState {
  isInstalling: boolean;
  selected: MetaCrawler;

}

export class CrawlerSelector extends React.Component<CrawlerSelectorProps, CrawlerSelectorState> {

  private crawlers: object[];

  constructor(props: CrawlerSelectorProps, context: CrawlerSelectorState) {
    super(props, context);
    this.state = {
      selected: null,
      isInstalling: false,
    };
  }

  public componentWillMount(): void {
    this.getMetaCrawlers();
  }

  public getMetaCrawlers(): void {
    // todo. getting MetaCrawler list
    let crawlers = [
      {
        'id': '1',
        'name': 'WMI',
        'description': 'WMI DESCRIPTION',
      },
      {
        'id': '2',
        'name': 'SNMP',
        'description': 'SNMP DESCRIPTION',
      },
      {
        'id': '3',
        'name': 'JMX',
        'description': 'JMX DESCRIPTION',
      },
    ];

    let crawlerOptions = [];
    let crawler: any;
    for (crawler of crawlers) {
      let option = {
        key: crawler.id,
        text: crawler.name,
        value: crawler.name,
        icon: 'check', // or close?
      };
      crawlerOptions.push(option);
    }

    this.crawlers = crawlerOptions;
  }

  public handleCrawlerSelection(e: any, data: any): void {
    this.setState({
      selected: data.value,
    });
    this.checkInstall();
  }

  public checkInstall(): void {
    this.setState({
      isInstalling: true,
    });
    let that = this;
    setInterval(() => {
      this.setState({
        isInstalling: false,
      });
    },          1500);
  }

  public render(): JSX.Element {

    return (
      <Container fluid>
        <Segment raised>
          <Loader active={this.state.isInstalling} size='large' >Installing the Crawler</Loader>
          <Icon name='checkmark' /> Choose a Crawler type.
          <br />
          <br />
          <Grid>
            <Grid.Row>
              <Grid.Column width='4'>
                <Dropdown openOnFocus
                  placeholder='Select Crawler' selection options={this.crawlers} onChange={this.handleCrawlerSelection.bind(this)} />

                <br />
                <br />
              </Grid.Column>
              <Grid.Column>
                <CrawlerAuthInputs crawler={this.state.selected} />
              </Grid.Column>
            </Grid.Row>
          </Grid>
        </Segment>
      </Container>
    );
  }
}

export interface CrawlerAuthInputsProps {
  crawler?: MetaCrawler;
}

export interface CrawlerAuthInputsState {
  isVerifying: boolean;
}

export class CrawlerAuthInputs extends React.Component<CrawlerAuthInputsProps, CrawlerAuthInputsState> {

  private data: object[];
  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
      isVerifying: false,
    };
  }

  public componentWillMount(): void {
    this.data = [
      {
        'id': '1',
        'metaInputType': {
          'id': '1',
          'name': 'Text',
        },
        'name': 'Community',
        'required': 'true',
        'defaultValue': 'public',
        'keyName': 'Community',
        'keyValue': '',
        'pattern': 'regex...',
      },
      {
        'id': '2',
        'metaInputType': {
          'id': '2',
          'name': 'Radio',
        },
        'name': 'AuthType',
        'required': 'true',
        'defaultValue': '',
        'keyName': 'AuthType',
        'keyValue': 'MD5|SHA',
        'pattern': 'regex...',
      },
    ];
  }

  public handleVerify(): void {
    this.setState({
      isVerifying: true,
    });
  }

  public renderRow(item: any, index: number): JSX.Element {
    let elem = new Array();
    if (item.metaInputType.name === 'Text') {
      elem.push(<Input placeholder={item.defaultValue} key={0} />);
    } else if (item.metaInputType.name === 'Radio') {
      let itemValues = item.keyValue.split('|');
      let idx = 0;
      for (let itemValue of itemValues) {
        elem.push(<Radio
          key={idx++}
          label={itemValue}
          name='radioGroup'
          value={itemValue}
        />);
      }
    }

    return <Table.Row key={index}>
      <Table.Cell collapsing>{item.keyName}</Table.Cell>
      <Table.Cell >{elem}</Table.Cell>
    </Table.Row >;
  }

  public render(): JSX.Element {
    if (this.props.crawler === null) {
      return null;
    }
    return (
      <Table basic='very' celled collapsing >
        <Table.Header>
          <Table.Row>
            <Table.HeaderCell colSpan='2'>{this.props.crawler} 접속 정보</Table.HeaderCell>
          </Table.Row>
        </Table.Header>

        <Table.Body>
          {this.data.map((item: any, index: number) => (
            this.renderRow(item, index)
          ))}
        </Table.Body>

        <Table.Footer>
          <Table.Row>
            <Table.HeaderCell />
            <Table.HeaderCell colSpan='2'>
              <Button primary floated={'right'} onClick={this.handleVerify.bind(this)} loading={this.state.isVerifying}>Verify</Button>
            </Table.HeaderCell>
          </Table.Row>

        </Table.Footer>
      </Table>
    );
  }
}

export interface SensorItemSelectorProps {

}

export interface SensorItemSelectorState {

}

export class SensorItemSelector extends React.Component<SensorItemSelectorProps, SensorItemSelectorState> {

  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
    };
  }


  public render(): JSX.Element {
    return (
      <Accordion exclusive={false} styled>
        <Accordion.Title>
          <Icon name='dropdown' />
          <Checkbox label='CPU' />
        </Accordion.Title>
        <Accordion.Content>
          <Checkbox label='cpu.free' /><br />
          <Checkbox label='cpu.free' /><br />
        </Accordion.Content>

        <Accordion.Title>
          <Icon name='dropdown' />
          <Checkbox label='MEM' />
        </Accordion.Title>
        <Accordion.Content>
          <Checkbox label='cpu.free' /><br />
          <Checkbox label='cpu.free' /><br />
        </Accordion.Content>

      </Accordion>
    );
  }
}

export interface ETCSelectorProps {

}

export interface ETCSelectorState {
  interval: string;
}

export class ETCSelector extends React.Component<ETCSelectorProps, ETCSelectorState> {
  constructor(props: any, context: any) {
    super(props, context);
    // this.state = {
    //   interval: 5,
    // };
  }
  public handleIntervalChange(e: any, { value }: any): void {
    this.setState({ interval: value });
  }

  public render(): JSX.Element {
    return (
      <Table celled={true}>
        <Table.Body>
          <Table.Row>
            <Table.Cell collapsing>
              Interval
            </Table.Cell>
            <Table.Cell>
              <Form.Field>
                <Radio
                  label='5 seconds'
                  name='radioGroup'
                  value='5'
                  checked={this.state.interval === '5'}
                  onChange={this.handleIntervalChange}
                />
              </Form.Field>
              <Form.Field>
                <Radio
                  label='10 seconds'
                  name='radioGroup'
                  value='10'
                  checked={this.state.interval === '10'}
                  onChange={this.handleIntervalChange}
                />
              </Form.Field>
              <Form.Field>
                <Radio
                  label='15 seconds'
                  name='radioGroup'
                  value='15'
                  checked={this.state.interval === '15'}
                  onChange={this.handleIntervalChange}
                />
              </Form.Field>
            </Table.Cell>
          </Table.Row>
          <Table.Row>
            <Table.Cell collapsing>
              Notification
            </Table.Cell>
            <Table.Cell></Table.Cell>
          </Table.Row>
          <Table.Row>
            <Table.Cell collapsing>
              Warn Condition
            </Table.Cell>
            <Table.Cell></Table.Cell>
          </Table.Row>
        </Table.Body>
      </Table>
    );
  }
}
