import * as React from 'react';
import { Button, Table, Header, Container } from 'semantic-ui-react';
import { SensorList } from '@overflow/sensor/react/components/SensorList';
import { DetailContainer } from '@overflow/commons/react/component/DetailContainer';

import Probe from '@overflow/probe/api/model/Probe';
import Target from '@overflow/target/api/model/Target';


export interface StateProps {
  probe?: Probe;
  target?: Target;
}

export interface DispatchProps {
 onRead(id: string): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
  selected: Probe;
  targetTemp: any;
  isDetail: boolean;
  list: Probe[];
}


export class TargetDetail extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      selected: null,
      targetTemp: null,
      isDetail: false,
      list: null,
    };
  }

  public componentWillMount(): void {
    let data = {
      'id': '1',
      'probe': {
        'id': '1',
        'status': {
          'id': '1',
          'name': 'INITIAL',
        },
        'description': 'snoop probe',
        'domain': {
          'id': '1',
          'name': 'overFlow`s domain',
        },
      },
      'infra': {
        'id': '1',
        'type': {
          'id': '1',
          'name': 'MACHINE',
        },
      },
    };

    this.setState({targetTemp: data});
  }
  public handleBack(): void {
    console.log('handleBack');
  }

  public handleRemoveTarget(): void {
    alert('remove');
  }

  public render(): JSX.Element {

    if (this.props.probe === null) {
      return null;
    }

    const items = [
      { name: 'Info', child: <TargetBasicInfo target={this.state.targetTemp} /> },
      { name: 'Sensors', child: <SensorList target={this.props.target} /> },
    ];

    return (
      <Container fluid>
        <TargetBasicInfo target={this.state.targetTemp} />
        <SensorList target={this.props.target} />
      </Container>
    );
  }
}


export interface TargetBasicInfoProps {
  target?: Target;
}

export interface TargetBasicInfoState {

}

export class TargetBasicInfo extends React.Component<TargetBasicInfoProps, TargetBasicInfoState> {

  constructor(props: TargetBasicInfoProps, context: TargetBasicInfoState) {
    super(props, context);
    this.state = {
    };
  }


  public handleRemoveTarget(): void {
    alert('remove');
  }

  public render(): JSX.Element {
    return (
      <Container fluid>
        <Header as='h3' dividing>Target Info</Header>
        <Table celled={false}>
          <Table.Body>
            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>Name</Header>
              </Table.Cell>
              <Table.Cell>
                {this.props.target.probe.domain.name}
            </Table.Cell>
            </Table.Row>

            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>Type</Header>
              </Table.Cell>
              <Table.Cell>
                {this.props.target.infra.type.name}
            </Table.Cell>
            </Table.Row>

            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>Sensor count</Header>
              </Table.Cell>
              <Table.Cell>
                1
            </Table.Cell>
            </Table.Row>

            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>Created at</Header>
              </Table.Cell>
              <Table.Cell>
                {this.props.target.createDate}
            </Table.Cell>
            </Table.Row>

          </Table.Body>
          <Table.Footer>
            <Table.Row>
              <Table.HeaderCell colSpan='2'>
                <Button primary floated={'right'} negative onClick={this.handleRemoveTarget}>Remove</Button>
              </Table.HeaderCell>
            </Table.Row>
          </Table.Footer>
        </Table>

      </Container>
    );
  }
}
