import * as React from 'react';
import { Table, Button, Modal, Input, Header, Container, InputOnChangeData, ButtonProps } from 'semantic-ui-react';
import { TargetDetail } from './TargetDetail';
import Target from '@overflow/target/api/model/Target';
import Probe from '@overflow/probe/api/model/Probe';
import { ListContainer } from '@overflow/commons/react/component/ListContainer';
import {Discovery} from '../../../discovery/react/components/Discovery';

export interface StateProps {

}

export interface DispatchProps {
  onReadAllByProbe(probe: Probe): void;
  onTargetSelection(id: string): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
  selected: Target;
  openAddTarget: boolean;
  list: Target[];
}

export class TargetList extends React.Component<Props, State> {

  private data: any;
  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      selected: null,
      openAddTarget: false,
      list: null,
    };
  }


  public handleAddTarget(event: React.MouseEvent<HTMLButtonElement>, data: ButtonProps): void {
    this.setState({
      openAddTarget: true,
    });
  }

  public handleSearch(result: Target[]): void {
    this.setState({
      list: result,
    });
  }

  public handleFilter(filterStr: string): void {
    if (filterStr === null) {
      this.setState({
        list: this.data,
      });
      return;
    }
    let founds = new Array();
    for (let probe of this.data) {
      if (probe.metaProbeStatus.name.indexOf(filterStr) !== -1) {
        founds.push(probe);
      }
    }
    this.setState({
      list: founds,
    });
  }

  public render(): JSX.Element {
    let targetList =
      <Container fluid>
        {/*search bar  */}
        <Button content='Discovery' icon='search' labelPosition='left' floated='right' positive onClick={this.handleAddTarget.bind(this)} />
        <TargetTable onSelectTarget={this.handleSelectedTarget}/>
        <br />

        <Modal
          open={this.state.openAddTarget}
        >
          {/*<Modal.Header>*/}
            {/*Adding a Target*/}
          {/*</Modal.Header>*/}
          <Modal.Content>
            <Discovery/>
          </Modal.Content>
          <Modal.Actions>
            <Button negative onClick={() => this.setState({ openAddTarget: false })}>Cancel</Button>
            <Button positive labelPosition='right' icon='checkmark' content='Done' />
          </Modal.Actions>
        </Modal>
      </Container>;
    return (
      <ListContainer
        contents={targetList}
        data={this.data}
        onSearch={this.handleSearch.bind(this)}
        filter={null}
      />
    );
  }

  private handleSelectedTarget = (target: Target): void => {
    console.log('handleSelectedTarget ');
    this.setState({selected: target});

    this.props.onTargetSelection(String(target.id));
  }
}

export interface TargetTableProps {
  onSelectTarget?:((target:Target) => void);
}

export interface TargetTableState {
  list: Array<Target>;
  selected: Target;
}

export class TargetTable extends React.Component<TargetTableProps, TargetTableState> {
  private data: any;

  constructor(props: TargetTableProps, context: TargetTableState) {
    super(props, context);
    this.state = {
      selected: null,
      list: [],
    };
  }

  public componentWillMount(): void {
    this.data = [
      {
        'id': '1',
        'probe': {
          'id': '1',
          'status': {
            'id': '1',
            'name': 'INITIAL',
          },
          'description': 'snoop probe',
          'domain': {
            'id': '1',
            'name': 'overFlow`s domain',
          },
        },
        'infra': {
          'id': '1',
          'type': {
            'id': '1',
            'name': 'MACHINE',
          },
        },
      },

      {
        'id': '11',
        'probe': {
          'id': '1',
          'status': {
            'id': '1',
            'name': 'INITIAL',
          },
          'description': 'snoop probe',
          'domain': {
            'id': '1',
            'name': 'overFlow`s domain',
          },
        },
        'infra': {
          'id': '1',
          'type': {
            'id': '1',
            'name': 'MACHINE',
          },
        },
      },

      {
        'id': '21',
        'probe': {
          'id': '1',
          'status': {
            'id': '1',
            'name': 'INITIAL',
          },
          'description': 'snoop probe',
          'domain': {
            'id': '1',
            'name': 'overFlow`s domain',
          },
        },
        'infra': {
          'id': '3',
          'type': {
            'id': '2',
            'name': 'HOST',
          },
        },
      },
    ];

    this.setState({list:this.data});
  }

  public handleSelect(selectedTarget: Target): void {

    console.log(selectedTarget.id);
    this.setState({
      selected: selectedTarget,
    });

    this.props.onSelectTarget(selectedTarget);
  }

  public render(): JSX.Element {
    return (
      <Container fluid>
        <Table celled selectable striped>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell textAlign={'center'}>No.</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Type</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Name</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Version</Table.HeaderCell>
            </Table.Row>
          </Table.Header>

          <Table.Body>
            {this.state.list.map((target: Target, index: number) => (
              <Table.Row key={index} onClick={this.handleSelect.bind(this, target)}>
                <Table.Cell textAlign={'center'}>{index + 1}</Table.Cell>
                <Table.Cell textAlign={'center'}>{target.infra.type.name}</Table.Cell>
                <Table.Cell>{target.probe.domain.name}</Table.Cell>
                <Table.Cell>todo</Table.Cell>
              </Table.Row>
            ))}
          </Table.Body>
        </Table>
      </Container>
    );
  }

}



